@@ -36,11 +36,10 @@ c
             call cgetlf(p1, g)
          endif   
          po = p2
-         call clorep(init, g, p2, po)
+
+c          next is no good if the zenith angle is not isotropic as in
+c          the case of muon decay.
+c         call clorep(init, g, p2, po)
+c
+         call cloreb(init, g, p2, po)
        end
-
-
-
-
-
-
