@@ -134,7 +134,13 @@ c          save present conditions
          NoOfSites2 = NoOfSites
          EndLevel2 = EndLevel
          if(Job .eq. ' ') then
-                !     no msg at all
+            if(SeedFile .ne. ' ') then
+c                  open seed file for output
+               write(msg, *) 'opening SeedFile=',
+     *         SeedFile(1:klena(SeedFile))
+               call cerrorMsg(msg, 1)
+               open(SeedFileDev, file=SeedFile, form='formatted')
+            endif               
          elseif(Job .eq. 'skeleton') then
             call
      *      cerrorMsg('  ********** skeleton making **********', 1)
@@ -145,10 +151,17 @@ c               save skeleton inf. in skelotonFile file.
             call cwriteParam(TempDev, 1)
             close(TempDev)
 c                open SeedFile 
-            write(msg, *) 'opening SeedFile=',
-     *      SeedFile(1:klena(SeedFile))
-            call cerrorMsg(msg, 1)
-            open(SeedFileDev, file=SeedFile, form='formatted')
+            if(SeedFile .eq. ' ') then
+c                error. you need file
+               write(msg, *)
+     *         ' SeedFile must not be blank for skelton making'
+               call cerrorMsg(msg, 0)
+            else
+               write(msg, *) 'opening SeedFile=',
+     *         SeedFile(1:klena(SeedFile))
+               call cerrorMsg(msg, 1)
+               open(SeedFileDev, file=SeedFile, form='formatted')
+            endif
          endif
       elseif(Job   .eq. 'flesh') then
 c             don't worry about KEminObs2 etc.  They have been read
@@ -171,11 +184,15 @@ c                to deeper detph than skeleton
              call cerrorMsg('EndLevel must be >= skelton time', 0)
           endif
 c                open SeedFile
-          write(msg, *) 'opening SeedFFile=', 
+          if(SeedFile .eq. ' ') then
+             write(*, *) ' SeedFile must not be blank for flesh job'
+             call cerrorMsg(msg, 0)
+          else
+             write(msg, *) 'opening SeedFFile=', 
      *        SeedFile(1:klena(SeedFile))
-          call cerrorMsg(msg, 1)
-          open(SeedFileDev, file=SeedFile, form='formatted')
-
+             call cerrorMsg(msg, 1)
+             open(SeedFileDev, file=SeedFile, form='formatted')
+          endif
       else
            write(msg,*) ' Job=',Job, ' undefined'
            call cerrorMsg(msg, 0)
