@@ -9,6 +9,8 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
+#include "Ztrack.h"
+#include "Ztrackv.h"
 
 c          ///////////
       integer nl, nth
@@ -51,6 +53,7 @@ c            observation level information
       eth(10) = 200.d-3
       eth(11) = 500.d-3
       eth(12) = 1.d0
+
 c      ////////////
       ntha = 1  !  for each ptcle out put use only 1 threshold
 c     /////////////
@@ -72,8 +75,9 @@ c     *  After this is executed, event generation starts.
 c     *
       subroutine chookBgEvent
       implicit none
-#include "Ztrack.h"
 #include "Zmanagerp.h"
+#include "Ztrack.h"
+#include "Ztrackv.h"
 
 c          ///////////
       integer nl, nth
@@ -84,10 +88,6 @@ c          ///////////
       integer ng, ne, nmu, nh, ntha
       real*8 eth
 c     //////////////
-
-
-
-
       record /track/ inci
       record /coord/ angle
 
@@ -95,10 +95,6 @@ c     //////////////
 c     //////////////
       integer i, j
       integer seed(2)
-c      write(*, *) ' bigin event generation'
-      call cqIniRn(seed)
-c      write(*,*) ' seed=', seed
-c      call cwriteSeed
       do i = 1, nl
          do j = 1, ntha
             ng(j, i) = 0
@@ -107,10 +103,11 @@ c      call cwriteSeed
             nmu(j, i) = 0
          enddo
       enddo
-      write(*, *)
-      call cqIncident(inci, angle)
-      write(*,'(i7,i4,g13.4,3f10.7)') EventNo, inci.p.code, inci.p.fm.e,
-     *  -angle.r(1),  -angle.r(2), -angle.r(3)      
+
+c      write(*, *)
+c      call cqIncident(inci, angle)
+c      write(*,'(i7,i4,g13.4,3f10.7)') EventNo, inci.p.code, inci.p.fm.e,
+c     *  -angle.r(1),  -angle.r(2), -angle.r(3)      
       end
       subroutine ccount(nc, aTrack)
       implicit none
@@ -150,6 +147,7 @@ c
       implicit none
 #include "Zcode.h"
 #include "Ztrack.h"
+#include "Ztrackv.h"
 #include  "Zheavyp.h"
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
@@ -170,7 +168,7 @@ c          ///////////
       integer ng, ne, nmu, nh, ntha
       real*8 eth
 c     //////////////
-
+      real*8 depth
       integer iij
 
 
@@ -181,10 +179,10 @@ c     0 (within the computational accuracy).
 c
 c      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
        if( id .eq. 2) then
+           call cqIncident(inci, angle)
            iij = aTrack.p.code  
 c          call cgpid(iij, ptclid)
            if(iij .eq. kelec ) then
-c     call cqIncident(inci, angle)
               call ccount(ne, aTrack)
 c              ne(aTrack.where) = ne(aTrack.where) + 1
            elseif(iij  .eq. kphoton ) then
@@ -204,24 +202,42 @@ c                 nh(aTrack.where) = nh(aTrack.where) + 1
 
 c            output typical quantities.
 c         id .eq. 2 below  if want otuput
-        if(id .eq. 2 .and. aTrack.where .eq.  8 ) then
-         if(aTrack.p.code .ne. kneue .and. aTrack.p.code .ne. 
-     *    kneumu) then
-       write(*,
-     *  '(i2,1x,i2,1x,f12.2, g13.4, f12.2,1x, f12.2,1x,f7.4,i3)')
+c        if(id .eq. 2 .and. aTrack.where .eq.  8 ) then
+c        if(id .eq. 2 .and. aTrack.where .eq.  1 ) then
+        if(id .eq. 2 ) then
+c         if(aTrack.p.code .ne. kneue .and. aTrack.p.code .ne. 
+c     *    kneumu) then
+           call cwhere2dep(aTrack.where, depth)
+c           write(*,*) int(depth/10. +0.001),
+           write(*,*)
+     *     aTrack.p.code,
+c     *  aTrack.p.subcode,
+c     *     aTrack.p.charge, 
+c     *     sngl(aTrack.p.fm.e-aTrack.p.mass),
+c     *      sngl(aTrack.vec.coszenith),
+c     *      sngl(inci.p.fm.p(4)-inci.p.mass)/
+c     *      Code2massN(int(inci.p.code)),
+c     *      inci.p.code,
+c     *     aTrack.pos.xyz.x, aTrack.pos.xyz.y,  aTrack.pos.xyz.z, 
+     *    sngl(aTrack.vec.w.x), sngl(aTrack.vec.w.y), 
+     *    sngl(aTrack.vec.w.z), 
+     *     aTrack.vec.w.x**2+aTrack.vec.w.y**2+aTrack.vec.w.z**2
+c     
+c       write(*,
+c     *  '(i2,1x,i2,1x,f12.2, g13.4, f12.2,1x, f12.2,1x,f7.4,i3)')
 c     * nev, 
 c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
-     *  aTrack.p.charge,  !  charge,  integer*2 
-     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
+c     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
+c     *  aTrack.p.charge,  !  charge,  integer*2 
+c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
-     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y),  !  x, y in m
+c     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
+c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y),  !  x, y, erg in m
 c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
 c     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
 c     * sngl(-angle.r(3)) ,
-     * sngl(aTrack.vec.coszenith),  ! cos of zenith angle
+c     * sngl(aTrack.vec.coszenith),  ! cos of zenith angle
 c     * sngl(inci.p.fm.p(4)-inci.p.mass)/Code2massN(int(inci.p.code)),
 c     * inci.p.code
 c         if(aTrack.p.code .eq. kelec) then
@@ -229,7 +245,7 @@ c            write(*, *) aTrack.where
 c         endif
 c      endif
 c         you may need in some case other information such as
-     *  aTrack.p.subcode   ! sub code of the particle integer*2
+c     *  aTrack.p.subcode   ! sub code of the particle integer*2
 c       aTrack.p.mass      ! mass 
 c       aTrack.wgt         ! weight of the particle (may not be 1. if
 c                           ! ThinSampling =T)
@@ -243,10 +259,26 @@ c     *     then
 c           ng = ng+1
 c           sumg = sumg + aTrack.p.fm.e
 
-        endif
+c        endif
       endif
       end
+      subroutine cwhere2dep(where, depth)
+      implicit none
+#include "Zcoord.h"
+#include "Zpos.h"
+#include "Zmagfield.h"
+#include "Zobs.h"
+#include "Zobsv.h"
+ 
+      integer*2 where
+      real*8 depth
+      if(where .le. 0 .or. where .gt. NoOfSites) then
+         write(*,*) where, NoOfSites
+         stop 'error'
+      endif
 
+      depth =ObsSites(where).pos.depth
+      end
 c    *********************************** hook for end of 1 event
 c    * At this moment, 1 event generation has been ended.
 c    *
@@ -269,7 +301,7 @@ c    *
 c          ///////////
       integer nl, nth
       parameter (nl = 20, nth=12)
-      common /testcos/eth(nth),
+      common /testcos/ eth(nth),
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
@@ -280,10 +312,13 @@ c     //////////////
 
 c          ///////////
       real*8  fdepth, bsin, teta, fai, sumsize
-      real*8  cgetBsin
+      real*8  cgetBsin, sumx, sumy
+      real*8 avex,  avey, sume
+      integer nnew
 c     //////////////
-c      call cqIncident(inci, angle)
+c       call cqIncident(inci, angle)
 c      write(*,*) inci.vec.coszenith, angle.r(3)
+
       if(ObserveAS) then
          call cqFirstID(fdepth)
          fdepth = fdepth * 0.1         ! in g/cm2
@@ -301,10 +336,10 @@ c         write(*, *) (ASObsSites(i).esize, i=1, NoOfASSites)
 c                   size weighted age
 c         write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites) 
          sumsize = 0.
-         write(*, *)
+c         write(*, *)
         do j = 1, ntha
           if(ntha .gt. 1) then
-             write(*,*) j
+c             write(*,*) j
           endif
            do i = 1, NoOfASSites
               sumsize = sumsize + ASObsSites(i).esize
@@ -320,10 +355,8 @@ c     *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)
             enddo
          enddo
       endif
-c      write(*, *)
+
       end
-
-
 c     ********************************* hook for end of a run
 c     *  all events have been created or time lacks
 c     *
